==> dvdisaster-0.72.3.tar.bz2: dvdisaster-0.72.3/documentation/ru/qa10.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2010 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3><a name="top">Технические вопросы</a></h3>

<a href="#nls">2.1 На какие языки переведена программа?</a><p>
<a href="#media">2.2 Какие типы носителей поддерживаются?</a><p>
<a href="#filesystem">2.3 Какие файловые системы поддерживаются?</a><p>
<a href="#aspi">2.4 Что означает "SPTI" и "ASPI"?</a><p>

<hr><p>

<b><a name="nls">2.1 На какие языки переведена программа?</a></b><p>

Текущая версия dvdisaster содержит экранные тексты на следующих языках:<p>

<table>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Чешский</td><td>--</td><td>до версии 0.66</td></tr>
<tr><td></td><td>Английский</td><td>--</td><td>полный</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Немецкий</td><td>--</td><td>полный</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Итальянский</td><td>--</td><td>до версии 0.65</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Русский</td><td>--</td><td>полный</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Португальский</td><td>--</td><td>полный<td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Шведский</td><td>--</td><td>до версии 0.70</td></tr>
</table><p>

Переводчики для других языков - добро пожаловать!<p>

dvdisaster автоматически получает языковые настройки из операционной системы.
Если локальный язык еще не поддерживается, то будет использоваться английский текст. 
С помощью переменных окружения можно выбрать другие языки.<p>

Пример для оболочки bash и немецкого языка:

<pre>export LANG=de_DE</pre>

Если специальные символы, такие как немецкие умлауты, отображаются неправильно,
попробуйте следующее:<p>

<tt>export OUTPUT_CHARSET=iso-8859-1</tt> (X11, XTerm)

<div align=right><a href="#top">&uarr;</a></div>


<b><a name="media">2.2 Какие типы носителей поддерживаются?</a></b><p>

dvdisaster поддерживает (пере-)записываемые CD и DVD. <br>
Носители с многосессионными записями или с защитой от копирования <i>не</i> могут быть использованы.<p>

Пригодные носители по типу:<p>

<b>CD-R, CD-RW</b><p>

<ul>
 <li>поддерживаются только Data CD.</li>
</ul>

<b>DVD-R, DVD+R</b><p>

<ul>
<li>Дополнительные ограничения неизвестны.</li>
</ul>

<b>DVD-R DL, DVD+R DL (два слоя)</b>
<ul>
<li>Привод должен быть способен <a href="qa20.php#dvdrom">идентифицировать тип носителя</a>.
Обычно это имеет место только в тех случаях, когда приводы могут также и писать на двухслойный носитель.</li>
</ul>

<b>DVD-RW, DVD+RW</b><p>

<ul>
<li>Некоторые приводы сообщают неправильные <a href="qa20.php#rw">размеры образов</a>.<br>
Выход из положения: определяйте размер образа из файловой системы ISO/UDF или файла ECC/RS02.
</li></ul>

<b>DVD-RAM</b><p>
<ul>
<li>Пригодны только, если записывать с помощью ISO/UDF образов, как DVD-R/-RW;</li>
<li>Не поддерживаются, если используются как извлекаемый носитель / для пакетной записи.</li>
<li>То же самое и с распознаванием <a href="qa20.php#rw">размера образа</a>,
как уже упоминалось выше.</li>
</ul>

<b>Непригодные типы</b> (образ нельзя извлечь):<p>
DVD-ROM (печатаемые DVD), CD-Audio и CD-Video.

<div align=right><a href="#top">&uarr;</a></div><p>


<b><a name="filesystem">2.3 Какие файловые системы поддерживаются?</a></b><p>

dvdisaster работает исключительно на уровне образа,
доступ к которому осуществляется посекторно.
Это означает, что не имеет значения, под какую файловую систему сформатирован носитель.<p>

Поскольку dvdisaster как не знает, так и не использует структуру файловой системы,
он не может исправлять логические ошибки на уровне файловой системы.
Он не может восстанавливать потерянные или удаленные файлы.
<div align=right><a href="#top">&uarr;</a></div><p>


<b><a name="aspi">2.4 Что означает "SPTI" и "ASPI"?</a></b><p>

Windows 98 и ME используют драйвера, называемые "ASPI", для доступа к приводам CD/DVD.
Windows NT и ее наследники обеспечивают схожую функциональность
через интерфейс, названный "SPTI", но все еще допускают установку
дополнительных ASPI драйверов.<p>

<i>&gt;&nbsp; Установка ASPI в среде Windows NT/2000/XP - за и против:</i><p>

<table>
<tr valign=top><td>+</td><td>Для доступа к приводам не требуются прав администратора.</td></tr>
<tr valign=top><td>-</td><td>ASPI не очень хорошо отображает приводы на буквы устройств Windows.</td></tr>
<tr valign=top><td>-</td><td>Некоторые программы для записи на CD/DVD устанавливают
свои собственные драйвера ASPI. Установка еще одного драйвера ASPI может вызвать конфликт 
с существующим ПО.</td></tr>
</table><p>

<i>&gt;&nbsp; Какие версии ASPI рекомендуются для использования с dvdisaster?</i><p>

Adaptec предоставляет свои драйверы ASPI для бесплатного скачивания.
Иногда у версий 4.72.* есть трудности распознавания приводов в среде
Windows 2000/XP. Понижение версии до 4.60 обычно помогает в таких
случаях.<p>

<i>&gt;&nbsp; Неправильные буквы дисков при использовании ASPI!</i><p>

Драйвера ASPI используют свою собственную систему идентификации приводов, которая
не поддерживает схему буквенного обозначения приводов Windows.<br>
Чтобы обеспечить унифицированный доступ к SPTI и ASPI,
dvdisaster пытается угадать отображение приводов ASPI на буквенные обозначения.
Это, однако, не работает во всех конфигурациях.<p>

Функция --list распечатывает
текущее отображение букв приводов.<p>

<i>&gt;&nbsp; Как сделать выбор между SPTI и ASPI?</i><p>

dvdisaster автоматически сделает выбор между SPTI и ASPI, 
делая предпочтение в пользу SPTI, если оба драйвера присутствуют. 
Использование ASPI может быть сделано принудительно; подробности смотрите в описании
функции --list.

<div align=right><a href="#top">&uarr;</a></div><p>

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/ru/qa10.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2012 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<h3 class="top"><a name="top">Технические вопросы</a></h3>

<a href="#nls">2.1 На какие языки переведена программа?</a><p>
<a href="#media">2.2 Какие типы носителей поддерживаются?</a><p>
<a href="#filesystem">2.3 Какие файловые системы поддерживаются?</a><p>

<hr><p>

<b><a name="nls">2.1 На какие языки переведена программа?</a></b><p>

Текущая версия dvdisaster содержит экранные тексты на следующих языках:<p>

<table>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Чешский</td><td>--</td><td>полный</td></tr>
<tr><td></td><td>Английский</td><td>--</td><td>полный</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Немецкий</td><td>--</td><td>полный</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Итальянский</td><td>--</td><td>до версии 0.65</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Русский</td><td>--</td><td>полный</td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Португальский</td><td>--</td><td>полный<td></tr>
<tr><td>&nbsp;&nbsp;&nbsp;</td><td>Шведский</td><td>--</td><td>до версии 0.70</td></tr>
</table><p>

Переводчики для других языков - добро пожаловать!<p>

dvdisaster автоматически получает языковые настройки из операционной системы.
Если локальный язык еще не поддерживается, то будет использоваться английский текст. 
С помощью переменных окружения можно выбрать другие языки.<p>

Пример для оболочки bash и немецкого языка:

<pre>export LANG=de_DE</pre>

Если специальные символы, такие как немецкие умлауты, отображаются неправильно,
попробуйте следующее:<p>

<tt>export OUTPUT_CHARSET=iso-8859-1</tt> (X11, XTerm)

<div class="talignr"><a href="#top">&uarr;</a></div>


<b><a name="media">2.2 Какие типы носителей поддерживаются?</a></b><p>

dvdisaster поддерживает (пере-)записываемые CD и DVD. <br>
Носители с многосессионными записями или с защитой от копирования <i>не</i> могут быть использованы.<p>

Пригодные носители по типу:<p>

<b>CD-R, CD-RW</b><p>

<ul>
 <li>поддерживаются только Data CD.</li>
</ul>

<b>DVD-R, DVD+R</b><p>

<ul>
<li>Дополнительные ограничения неизвестны.</li>
</ul>

<b>DVD-R DL, DVD+R DL (два слоя)</b>
<ul>
<li>Привод должен быть способен <a href="qa20.php#dvdrom">идентифицировать тип носителя</a>.
Обычно это имеет место только в тех случаях, когда приводы могут также и писать на двухслойный носитель.</li>
</ul>

<b>DVD-RW, DVD+RW</b><p>

<ul>
<li>Некоторые приводы сообщают неправильные <a href="qa20.php#rw">размеры образов</a>.<br>
Выход из положения: определяйте размер образа из файловой системы ISO/UDF или файла ECC/RS02.
</li></ul>

<b>DVD-RAM</b><p>
<ul>
<li>Пригодны только, если записывать с помощью ISO/UDF образов, как DVD-R/-RW;</li>
<li>Не поддерживаются, если используются как извлекаемый носитель / для пакетной записи.</li>
<li>То же самое и с распознаванием <a href="qa20.php#rw">размера образа</a>,
как уже упоминалось выше.</li>
</ul>

<b>Непригодные типы</b> (образ нельзя извлечь):<p>
DVD-ROM (печатаемые DVD), CD-Audio и CD-Video.

<div class="talignr"><a href="#top">&uarr;</a></div><p>


<b><a name="filesystem">2.3 Какие файловые системы поддерживаются?</a></b><p>

dvdisaster работает исключительно на уровне образа,
доступ к которому осуществляется посекторно.
Это означает, что не имеет значения, под какую файловую систему сформатирован носитель.<p>

Поскольку dvdisaster как не знает, так и не использует структуру файловой системы,
он не может исправлять логические ошибки на уровне файловой системы.
Он не может восстанавливать потерянные или удаленные файлы.
<div class="talignr"><a href="#top">&uarr;</a></div><p>

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
